==> POE-Component-IRC-PluginBundle-Toys-1.001001.tar.gz: POE-Component-IRC-PluginBundle-Toys-1.001001/README.md <==
# NAME

POE::Component::IRC::Plugin::Toys - a collection of fun-to-have plugins

# CONTENTS

This distribution provides the following
[POE::Component::IRC](https://metacpan.org/pod/POE::Component::IRC) plugins:

- [POE::Component::IRC::Plugin::AlarmClock](https://metacpan.org/pod/POE::Component::IRC::Plugin::AlarmClock)   IRC alarm clock
- [POE::Component::IRC::Plugin::CoinFlip](https://metacpan.org/pod/POE::Component::IRC::Plugin::CoinFlip)    flip coins on IRC
- [POE::Component::IRC::Plugin::Fortune](https://metacpan.org/pod/POE::Component::IRC::Plugin::Fortune)     fortune cookies
- [POE::Component::IRC::Plugin::Magic8Ball](https://metacpan.org/pod/POE::Component::IRC::Plugin::Magic8Ball)  Magic 8 Ball
- [POE::Component::IRC::Plugin::SigFail](https://metacpan.org/pod/POE::Component::IRC::Plugin::SigFail)  make witty error/no result messages
- [POE::Component::IRC::Plugin::Thanks](https://metacpan.org/pod/POE::Component::IRC::Plugin::Thanks)    make witty responses to "thank you"s
- [POE::Component::IRC::Plugin::YouAreDoingItWrong](https://metacpan.org/pod/POE::Component::IRC::Plugin::YouAreDoingItWrong) show people what they are doing wrong by giving links to
[www.doingitwrong.com](http://www.doingitwrong.com/) images

# EXAMPLES

This distribution contains `examples/` directory, with usage examples
of each plugin.

# REPOSITORY

Fork this module on GitHub:
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys)

# BUGS

To report bugs or request features, please use
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys/issues](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys/issues)

If you can't access GitHub, you can email your request
to `bug-POE-Component-IRC-PluginBundle-Toys at rt.cpan.org`

# AUTHOR

Zoffix Znet <zoffix at cpan.org>
([http://zoffix.com/](http://zoffix.com/), [http://haslayout.net/](http://haslayout.net/))

# LICENSE

You can use and distribute this module under the same terms as Perl itself.
See the `LICENSE` file included in this distribution for complete
details.

==> POE-Component-IRC-PluginBundle-Toys-1.001002.tar.gz: POE-Component-IRC-PluginBundle-Toys-1.001002/README.md <==
# NAME

POE::Component::IRC::Plugin::Toys - a collection of fun-to-have plugins

# CONTENTS

This distribution provides the following
[POE::Component::IRC](https://metacpan.org/pod/POE::Component::IRC) plugins:

- [POE::Component::IRC::Plugin::AlarmClock](https://metacpan.org/pod/POE::Component::IRC::Plugin::AlarmClock)   IRC alarm clock
- [POE::Component::IRC::Plugin::CoinFlip](https://metacpan.org/pod/POE::Component::IRC::Plugin::CoinFlip)    flip coins on IRC
- [POE::Component::IRC::Plugin::Fortune](https://metacpan.org/pod/POE::Component::IRC::Plugin::Fortune)     fortune cookies
- [POE::Component::IRC::Plugin::Magic8Ball](https://metacpan.org/pod/POE::Component::IRC::Plugin::Magic8Ball)  Magic 8 Ball
- [POE::Component::IRC::Plugin::SigFail](https://metacpan.org/pod/POE::Component::IRC::Plugin::SigFail)  make witty error/no result messages
- [POE::Component::IRC::Plugin::Thanks](https://metacpan.org/pod/POE::Component::IRC::Plugin::Thanks)    make witty responses to "thank you"s
- [POE::Component::IRC::Plugin::YouAreDoingItWrong](https://metacpan.org/pod/POE::Component::IRC::Plugin::YouAreDoingItWrong) show people what they are doing wrong by giving links to
[www.doingitwrong.com](http://www.doingitwrong.com/) images

# EXAMPLES

This distribution contains `examples/` directory, with usage examples
of each plugin.

# REPOSITORY

Fork this module on GitHub:
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys)

# BUGS

To report bugs or request features, please use
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys/issues](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-Toys/issues)

If you can't access GitHub, you can email your request
to `bug-POE-Component-IRC-PluginBundle-Toys at rt.cpan.org`

# AUTHOR

Zoffix Znet &lt;zoffix at cpan.org>
([http://zoffix.com/](http://zoffix.com/), [http://haslayout.net/](http://haslayout.net/))

# LICENSE

You can use and distribute this module under the same terms as Perl itself.
See the `LICENSE` file included in this distribution for complete
details.
